# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ServiceError.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ServiceError.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\342?\035\n\033coop.rchain.casper.protocol'),
  serialized_pb=_b('\n\x12ServiceError.proto\x1a\x15scalapb/scalapb.proto\" \n\x0cServiceError\x12\x10\n\x08messages\x18\x01 \x03(\tB \xe2?\x1d\n\x1b\x63oop.rchain.casper.protocolb\x06proto3')
  ,
  dependencies=[scalapb_dot_scalapb__pb2.DESCRIPTOR,])




_SERVICEERROR = _descriptor.Descriptor(
  name='ServiceError',
  full_name='ServiceError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='ServiceError.messages', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=77,
)

DESCRIPTOR.message_types_by_name['ServiceError'] = _SERVICEERROR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ServiceError = _reflection.GeneratedProtocolMessageType('ServiceError', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEERROR,
  '__module__' : 'ServiceError_pb2'
  # @@protoc_insertion_point(class_scope:ServiceError)
  })
_sym_db.RegisterMessage(ServiceError)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
