# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: DeployServiceV1.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import CasperMessage_pb2 as CasperMessage__pb2
from . import ServiceError_pb2 as ServiceError__pb2
from . import DeployServiceCommon_pb2 as DeployServiceCommon__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='DeployServiceV1.proto',
  package='casper.v1',
  syntax='proto3',
  serialized_options=_b('\342?+\n%coop.rchain.casper.protocol.deploy.v1\020\001(\001'),
  serialized_pb=_b('\n\x15\x44\x65ployServiceV1.proto\x12\tcasper.v1\x1a\x13\x43\x61sperMessage.proto\x1a\x12ServiceError.proto\x1a\x19\x44\x65ployServiceCommon.proto\x1a\x15scalapb/scalapb.proto\"M\n\x0e\x44\x65ployResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12\x10\n\x06result\x18\x02 \x01(\tH\x00\x42\t\n\x07message\"b\n\rBlockResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12&\n\tblockInfo\x18\x02 \x01(\x0b\x32\x11.casper.BlockInfoH\x00\x42\t\n\x07message\"W\n\x17VisualizeBlocksResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12\x11\n\x07\x63ontent\x18\x02 \x01(\tH\x00\x42\t\n\x07message\"U\n\x15MachineVerifyResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12\x11\n\x07\x63ontent\x18\x02 \x01(\tH\x00\x42\t\n\x07message\"k\n\x11\x42lockInfoResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12+\n\tblockInfo\x18\x02 \x01(\x0b\x32\x16.casper.LightBlockInfoH\x00\x42\t\n\x07message\"~\n\x19ListeningNameDataResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12\x36\n\x07payload\x18\x02 \x01(\x0b\x32#.casper.v1.ListeningNameDataPayloadH\x00\x42\t\n\x07message\"X\n\x18ListeningNameDataPayload\x12,\n\tblockInfo\x18\x01 \x03(\x0b\x32\x19.casper.DataWithBlockInfo\x12\x0e\n\x06length\x18\x02 \x01(\x05\"\x80\x01\n\x1a\x43ontinuationAtNameResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12\x37\n\x07payload\x18\x02 \x01(\x0b\x32$.casper.v1.ContinuationAtNamePayloadH\x00\x42\t\n\x07message\"e\n\x19\x43ontinuationAtNamePayload\x12\x38\n\x0c\x62lockResults\x18\x01 \x03(\x0b\x32\".casper.ContinuationsWithBlockInfo\x12\x0e\n\x06length\x18\x02 \x01(\x05\"l\n\x12\x46indDeployResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12+\n\tblockInfo\x18\x02 \x01(\x0b\x32\x16.casper.LightBlockInfoH\x00\x42\t\n\x07message\"\x80\x01\n\x1aPrivateNamePreviewResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12\x37\n\x07payload\x18\x02 \x01(\x0b\x32$.casper.v1.PrivateNamePreviewPayloadH\x00\x42\t\n\x07message\"(\n\x19PrivateNamePreviewPayload\x12\x0b\n\x03ids\x18\x01 \x03(\x0c\"o\n\x1aLastFinalizedBlockResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12&\n\tblockInfo\x18\x02 \x01(\x0b\x32\x11.casper.BlockInfoH\x00\x42\t\n\x07message\"W\n\x13IsFinalizedResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12\x15\n\x0bisFinalized\x18\x02 \x01(\x08H\x00\x42\t\n\x07message\"S\n\x12\x42ondStatusResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12\x12\n\x08isBonded\x18\x02 \x01(\x08H\x00\x42\t\n\x07message2\xa1\x08\n\rDeployService\x12@\n\x08\x64oDeploy\x12\x17.casper.DeployDataProto\x1a\x19.casper.v1.DeployResponse\"\x00\x12:\n\x08getBlock\x12\x12.casper.BlockQuery\x1a\x18.casper.v1.BlockResponse\"\x00\x12Q\n\x0cvisualizeDag\x12\x19.casper.VisualizeDagQuery\x1a\".casper.v1.VisualizeBlocksResponse\"\x00\x30\x01\x12V\n\x14machineVerifiableDag\x12\x1a.casper.MachineVerifyQuery\x1a .casper.v1.MachineVerifyResponse\"\x00\x12\x46\n\rshowMainChain\x12\x13.casper.BlocksQuery\x1a\x1c.casper.v1.BlockInfoResponse\"\x00\x30\x01\x12\x42\n\tgetBlocks\x12\x13.casper.BlocksQuery\x1a\x1c.casper.v1.BlockInfoResponse\"\x00\x30\x01\x12V\n\x13listenForDataAtName\x12\x17.casper.DataAtNameQuery\x1a$.casper.v1.ListeningNameDataResponse\"\x00\x12g\n\x1blistenForContinuationAtName\x12\x1f.casper.ContinuationAtNameQuery\x1a%.casper.v1.ContinuationAtNameResponse\"\x00\x12\x46\n\nfindDeploy\x12\x17.casper.FindDeployQuery\x1a\x1d.casper.v1.FindDeployResponse\"\x00\x12_\n\x13previewPrivateNames\x12\x1f.casper.PrivateNamePreviewQuery\x1a%.casper.v1.PrivateNamePreviewResponse\"\x00\x12^\n\x12lastFinalizedBlock\x12\x1f.casper.LastFinalizedBlockQuery\x1a%.casper.v1.LastFinalizedBlockResponse\"\x00\x12I\n\x0bisFinalized\x12\x18.casper.IsFinalizedQuery\x1a\x1e.casper.v1.IsFinalizedResponse\"\x00\x12\x46\n\nbondStatus\x12\x17.casper.BondStatusQuery\x1a\x1d.casper.v1.BondStatusResponse\"\x00\x42.\xe2?+\n%coop.rchain.casper.protocol.deploy.v1\x10\x01(\x01\x62\x06proto3')
  ,
  dependencies=[CasperMessage__pb2.DESCRIPTOR,ServiceError__pb2.DESCRIPTOR,DeployServiceCommon__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])




_DEPLOYRESPONSE = _descriptor.Descriptor(
  name='DeployResponse',
  full_name='casper.v1.DeployResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.DeployResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result', full_name='casper.v1.DeployResponse.result', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.DeployResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=127,
  serialized_end=204,
)


_BLOCKRESPONSE = _descriptor.Descriptor(
  name='BlockResponse',
  full_name='casper.v1.BlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.BlockResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockInfo', full_name='casper.v1.BlockResponse.blockInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.BlockResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=206,
  serialized_end=304,
)


_VISUALIZEBLOCKSRESPONSE = _descriptor.Descriptor(
  name='VisualizeBlocksResponse',
  full_name='casper.v1.VisualizeBlocksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.VisualizeBlocksResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='casper.v1.VisualizeBlocksResponse.content', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.VisualizeBlocksResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=306,
  serialized_end=393,
)


_MACHINEVERIFYRESPONSE = _descriptor.Descriptor(
  name='MachineVerifyResponse',
  full_name='casper.v1.MachineVerifyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.MachineVerifyResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='casper.v1.MachineVerifyResponse.content', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.MachineVerifyResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=395,
  serialized_end=480,
)


_BLOCKINFORESPONSE = _descriptor.Descriptor(
  name='BlockInfoResponse',
  full_name='casper.v1.BlockInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.BlockInfoResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockInfo', full_name='casper.v1.BlockInfoResponse.blockInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.BlockInfoResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=482,
  serialized_end=589,
)


_LISTENINGNAMEDATARESPONSE = _descriptor.Descriptor(
  name='ListeningNameDataResponse',
  full_name='casper.v1.ListeningNameDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.ListeningNameDataResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='casper.v1.ListeningNameDataResponse.payload', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.ListeningNameDataResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=591,
  serialized_end=717,
)


_LISTENINGNAMEDATAPAYLOAD = _descriptor.Descriptor(
  name='ListeningNameDataPayload',
  full_name='casper.v1.ListeningNameDataPayload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockInfo', full_name='casper.v1.ListeningNameDataPayload.blockInfo', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='length', full_name='casper.v1.ListeningNameDataPayload.length', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=719,
  serialized_end=807,
)


_CONTINUATIONATNAMERESPONSE = _descriptor.Descriptor(
  name='ContinuationAtNameResponse',
  full_name='casper.v1.ContinuationAtNameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.ContinuationAtNameResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='casper.v1.ContinuationAtNameResponse.payload', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.ContinuationAtNameResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=810,
  serialized_end=938,
)


_CONTINUATIONATNAMEPAYLOAD = _descriptor.Descriptor(
  name='ContinuationAtNamePayload',
  full_name='casper.v1.ContinuationAtNamePayload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockResults', full_name='casper.v1.ContinuationAtNamePayload.blockResults', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='length', full_name='casper.v1.ContinuationAtNamePayload.length', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=940,
  serialized_end=1041,
)


_FINDDEPLOYRESPONSE = _descriptor.Descriptor(
  name='FindDeployResponse',
  full_name='casper.v1.FindDeployResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.FindDeployResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockInfo', full_name='casper.v1.FindDeployResponse.blockInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.FindDeployResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1043,
  serialized_end=1151,
)


_PRIVATENAMEPREVIEWRESPONSE = _descriptor.Descriptor(
  name='PrivateNamePreviewResponse',
  full_name='casper.v1.PrivateNamePreviewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.PrivateNamePreviewResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='casper.v1.PrivateNamePreviewResponse.payload', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.PrivateNamePreviewResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1154,
  serialized_end=1282,
)


_PRIVATENAMEPREVIEWPAYLOAD = _descriptor.Descriptor(
  name='PrivateNamePreviewPayload',
  full_name='casper.v1.PrivateNamePreviewPayload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='casper.v1.PrivateNamePreviewPayload.ids', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1284,
  serialized_end=1324,
)


_LASTFINALIZEDBLOCKRESPONSE = _descriptor.Descriptor(
  name='LastFinalizedBlockResponse',
  full_name='casper.v1.LastFinalizedBlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.LastFinalizedBlockResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockInfo', full_name='casper.v1.LastFinalizedBlockResponse.blockInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.LastFinalizedBlockResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1326,
  serialized_end=1437,
)


_ISFINALIZEDRESPONSE = _descriptor.Descriptor(
  name='IsFinalizedResponse',
  full_name='casper.v1.IsFinalizedResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.IsFinalizedResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isFinalized', full_name='casper.v1.IsFinalizedResponse.isFinalized', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.IsFinalizedResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1439,
  serialized_end=1526,
)


_BONDSTATUSRESPONSE = _descriptor.Descriptor(
  name='BondStatusResponse',
  full_name='casper.v1.BondStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.BondStatusResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isBonded', full_name='casper.v1.BondStatusResponse.isBonded', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.BondStatusResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1528,
  serialized_end=1611,
)

_DEPLOYRESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_DEPLOYRESPONSE.oneofs_by_name['message'].fields.append(
  _DEPLOYRESPONSE.fields_by_name['error'])
_DEPLOYRESPONSE.fields_by_name['error'].containing_oneof = _DEPLOYRESPONSE.oneofs_by_name['message']
_DEPLOYRESPONSE.oneofs_by_name['message'].fields.append(
  _DEPLOYRESPONSE.fields_by_name['result'])
_DEPLOYRESPONSE.fields_by_name['result'].containing_oneof = _DEPLOYRESPONSE.oneofs_by_name['message']
_BLOCKRESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_BLOCKRESPONSE.fields_by_name['blockInfo'].message_type = DeployServiceCommon__pb2._BLOCKINFO
_BLOCKRESPONSE.oneofs_by_name['message'].fields.append(
  _BLOCKRESPONSE.fields_by_name['error'])
_BLOCKRESPONSE.fields_by_name['error'].containing_oneof = _BLOCKRESPONSE.oneofs_by_name['message']
_BLOCKRESPONSE.oneofs_by_name['message'].fields.append(
  _BLOCKRESPONSE.fields_by_name['blockInfo'])
_BLOCKRESPONSE.fields_by_name['blockInfo'].containing_oneof = _BLOCKRESPONSE.oneofs_by_name['message']
_VISUALIZEBLOCKSRESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_VISUALIZEBLOCKSRESPONSE.oneofs_by_name['message'].fields.append(
  _VISUALIZEBLOCKSRESPONSE.fields_by_name['error'])
_VISUALIZEBLOCKSRESPONSE.fields_by_name['error'].containing_oneof = _VISUALIZEBLOCKSRESPONSE.oneofs_by_name['message']
_VISUALIZEBLOCKSRESPONSE.oneofs_by_name['message'].fields.append(
  _VISUALIZEBLOCKSRESPONSE.fields_by_name['content'])
_VISUALIZEBLOCKSRESPONSE.fields_by_name['content'].containing_oneof = _VISUALIZEBLOCKSRESPONSE.oneofs_by_name['message']
_MACHINEVERIFYRESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_MACHINEVERIFYRESPONSE.oneofs_by_name['message'].fields.append(
  _MACHINEVERIFYRESPONSE.fields_by_name['error'])
_MACHINEVERIFYRESPONSE.fields_by_name['error'].containing_oneof = _MACHINEVERIFYRESPONSE.oneofs_by_name['message']
_MACHINEVERIFYRESPONSE.oneofs_by_name['message'].fields.append(
  _MACHINEVERIFYRESPONSE.fields_by_name['content'])
_MACHINEVERIFYRESPONSE.fields_by_name['content'].containing_oneof = _MACHINEVERIFYRESPONSE.oneofs_by_name['message']
_BLOCKINFORESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_BLOCKINFORESPONSE.fields_by_name['blockInfo'].message_type = DeployServiceCommon__pb2._LIGHTBLOCKINFO
_BLOCKINFORESPONSE.oneofs_by_name['message'].fields.append(
  _BLOCKINFORESPONSE.fields_by_name['error'])
_BLOCKINFORESPONSE.fields_by_name['error'].containing_oneof = _BLOCKINFORESPONSE.oneofs_by_name['message']
_BLOCKINFORESPONSE.oneofs_by_name['message'].fields.append(
  _BLOCKINFORESPONSE.fields_by_name['blockInfo'])
_BLOCKINFORESPONSE.fields_by_name['blockInfo'].containing_oneof = _BLOCKINFORESPONSE.oneofs_by_name['message']
_LISTENINGNAMEDATARESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_LISTENINGNAMEDATARESPONSE.fields_by_name['payload'].message_type = _LISTENINGNAMEDATAPAYLOAD
_LISTENINGNAMEDATARESPONSE.oneofs_by_name['message'].fields.append(
  _LISTENINGNAMEDATARESPONSE.fields_by_name['error'])
_LISTENINGNAMEDATARESPONSE.fields_by_name['error'].containing_oneof = _LISTENINGNAMEDATARESPONSE.oneofs_by_name['message']
_LISTENINGNAMEDATARESPONSE.oneofs_by_name['message'].fields.append(
  _LISTENINGNAMEDATARESPONSE.fields_by_name['payload'])
_LISTENINGNAMEDATARESPONSE.fields_by_name['payload'].containing_oneof = _LISTENINGNAMEDATARESPONSE.oneofs_by_name['message']
_LISTENINGNAMEDATAPAYLOAD.fields_by_name['blockInfo'].message_type = DeployServiceCommon__pb2._DATAWITHBLOCKINFO
_CONTINUATIONATNAMERESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_CONTINUATIONATNAMERESPONSE.fields_by_name['payload'].message_type = _CONTINUATIONATNAMEPAYLOAD
_CONTINUATIONATNAMERESPONSE.oneofs_by_name['message'].fields.append(
  _CONTINUATIONATNAMERESPONSE.fields_by_name['error'])
_CONTINUATIONATNAMERESPONSE.fields_by_name['error'].containing_oneof = _CONTINUATIONATNAMERESPONSE.oneofs_by_name['message']
_CONTINUATIONATNAMERESPONSE.oneofs_by_name['message'].fields.append(
  _CONTINUATIONATNAMERESPONSE.fields_by_name['payload'])
_CONTINUATIONATNAMERESPONSE.fields_by_name['payload'].containing_oneof = _CONTINUATIONATNAMERESPONSE.oneofs_by_name['message']
_CONTINUATIONATNAMEPAYLOAD.fields_by_name['blockResults'].message_type = DeployServiceCommon__pb2._CONTINUATIONSWITHBLOCKINFO
_FINDDEPLOYRESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_FINDDEPLOYRESPONSE.fields_by_name['blockInfo'].message_type = DeployServiceCommon__pb2._LIGHTBLOCKINFO
_FINDDEPLOYRESPONSE.oneofs_by_name['message'].fields.append(
  _FINDDEPLOYRESPONSE.fields_by_name['error'])
_FINDDEPLOYRESPONSE.fields_by_name['error'].containing_oneof = _FINDDEPLOYRESPONSE.oneofs_by_name['message']
_FINDDEPLOYRESPONSE.oneofs_by_name['message'].fields.append(
  _FINDDEPLOYRESPONSE.fields_by_name['blockInfo'])
_FINDDEPLOYRESPONSE.fields_by_name['blockInfo'].containing_oneof = _FINDDEPLOYRESPONSE.oneofs_by_name['message']
_PRIVATENAMEPREVIEWRESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_PRIVATENAMEPREVIEWRESPONSE.fields_by_name['payload'].message_type = _PRIVATENAMEPREVIEWPAYLOAD
_PRIVATENAMEPREVIEWRESPONSE.oneofs_by_name['message'].fields.append(
  _PRIVATENAMEPREVIEWRESPONSE.fields_by_name['error'])
_PRIVATENAMEPREVIEWRESPONSE.fields_by_name['error'].containing_oneof = _PRIVATENAMEPREVIEWRESPONSE.oneofs_by_name['message']
_PRIVATENAMEPREVIEWRESPONSE.oneofs_by_name['message'].fields.append(
  _PRIVATENAMEPREVIEWRESPONSE.fields_by_name['payload'])
_PRIVATENAMEPREVIEWRESPONSE.fields_by_name['payload'].containing_oneof = _PRIVATENAMEPREVIEWRESPONSE.oneofs_by_name['message']
_LASTFINALIZEDBLOCKRESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_LASTFINALIZEDBLOCKRESPONSE.fields_by_name['blockInfo'].message_type = DeployServiceCommon__pb2._BLOCKINFO
_LASTFINALIZEDBLOCKRESPONSE.oneofs_by_name['message'].fields.append(
  _LASTFINALIZEDBLOCKRESPONSE.fields_by_name['error'])
_LASTFINALIZEDBLOCKRESPONSE.fields_by_name['error'].containing_oneof = _LASTFINALIZEDBLOCKRESPONSE.oneofs_by_name['message']
_LASTFINALIZEDBLOCKRESPONSE.oneofs_by_name['message'].fields.append(
  _LASTFINALIZEDBLOCKRESPONSE.fields_by_name['blockInfo'])
_LASTFINALIZEDBLOCKRESPONSE.fields_by_name['blockInfo'].containing_oneof = _LASTFINALIZEDBLOCKRESPONSE.oneofs_by_name['message']
_ISFINALIZEDRESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_ISFINALIZEDRESPONSE.oneofs_by_name['message'].fields.append(
  _ISFINALIZEDRESPONSE.fields_by_name['error'])
_ISFINALIZEDRESPONSE.fields_by_name['error'].containing_oneof = _ISFINALIZEDRESPONSE.oneofs_by_name['message']
_ISFINALIZEDRESPONSE.oneofs_by_name['message'].fields.append(
  _ISFINALIZEDRESPONSE.fields_by_name['isFinalized'])
_ISFINALIZEDRESPONSE.fields_by_name['isFinalized'].containing_oneof = _ISFINALIZEDRESPONSE.oneofs_by_name['message']
_BONDSTATUSRESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_BONDSTATUSRESPONSE.oneofs_by_name['message'].fields.append(
  _BONDSTATUSRESPONSE.fields_by_name['error'])
_BONDSTATUSRESPONSE.fields_by_name['error'].containing_oneof = _BONDSTATUSRESPONSE.oneofs_by_name['message']
_BONDSTATUSRESPONSE.oneofs_by_name['message'].fields.append(
  _BONDSTATUSRESPONSE.fields_by_name['isBonded'])
_BONDSTATUSRESPONSE.fields_by_name['isBonded'].containing_oneof = _BONDSTATUSRESPONSE.oneofs_by_name['message']
DESCRIPTOR.message_types_by_name['DeployResponse'] = _DEPLOYRESPONSE
DESCRIPTOR.message_types_by_name['BlockResponse'] = _BLOCKRESPONSE
DESCRIPTOR.message_types_by_name['VisualizeBlocksResponse'] = _VISUALIZEBLOCKSRESPONSE
DESCRIPTOR.message_types_by_name['MachineVerifyResponse'] = _MACHINEVERIFYRESPONSE
DESCRIPTOR.message_types_by_name['BlockInfoResponse'] = _BLOCKINFORESPONSE
DESCRIPTOR.message_types_by_name['ListeningNameDataResponse'] = _LISTENINGNAMEDATARESPONSE
DESCRIPTOR.message_types_by_name['ListeningNameDataPayload'] = _LISTENINGNAMEDATAPAYLOAD
DESCRIPTOR.message_types_by_name['ContinuationAtNameResponse'] = _CONTINUATIONATNAMERESPONSE
DESCRIPTOR.message_types_by_name['ContinuationAtNamePayload'] = _CONTINUATIONATNAMEPAYLOAD
DESCRIPTOR.message_types_by_name['FindDeployResponse'] = _FINDDEPLOYRESPONSE
DESCRIPTOR.message_types_by_name['PrivateNamePreviewResponse'] = _PRIVATENAMEPREVIEWRESPONSE
DESCRIPTOR.message_types_by_name['PrivateNamePreviewPayload'] = _PRIVATENAMEPREVIEWPAYLOAD
DESCRIPTOR.message_types_by_name['LastFinalizedBlockResponse'] = _LASTFINALIZEDBLOCKRESPONSE
DESCRIPTOR.message_types_by_name['IsFinalizedResponse'] = _ISFINALIZEDRESPONSE
DESCRIPTOR.message_types_by_name['BondStatusResponse'] = _BONDSTATUSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DeployResponse = _reflection.GeneratedProtocolMessageType('DeployResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYRESPONSE,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.DeployResponse)
  })
_sym_db.RegisterMessage(DeployResponse)

BlockResponse = _reflection.GeneratedProtocolMessageType('BlockResponse', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKRESPONSE,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.BlockResponse)
  })
_sym_db.RegisterMessage(BlockResponse)

VisualizeBlocksResponse = _reflection.GeneratedProtocolMessageType('VisualizeBlocksResponse', (_message.Message,), {
  'DESCRIPTOR' : _VISUALIZEBLOCKSRESPONSE,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.VisualizeBlocksResponse)
  })
_sym_db.RegisterMessage(VisualizeBlocksResponse)

MachineVerifyResponse = _reflection.GeneratedProtocolMessageType('MachineVerifyResponse', (_message.Message,), {
  'DESCRIPTOR' : _MACHINEVERIFYRESPONSE,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.MachineVerifyResponse)
  })
_sym_db.RegisterMessage(MachineVerifyResponse)

BlockInfoResponse = _reflection.GeneratedProtocolMessageType('BlockInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKINFORESPONSE,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.BlockInfoResponse)
  })
_sym_db.RegisterMessage(BlockInfoResponse)

ListeningNameDataResponse = _reflection.GeneratedProtocolMessageType('ListeningNameDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTENINGNAMEDATARESPONSE,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.ListeningNameDataResponse)
  })
_sym_db.RegisterMessage(ListeningNameDataResponse)

ListeningNameDataPayload = _reflection.GeneratedProtocolMessageType('ListeningNameDataPayload', (_message.Message,), {
  'DESCRIPTOR' : _LISTENINGNAMEDATAPAYLOAD,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.ListeningNameDataPayload)
  })
_sym_db.RegisterMessage(ListeningNameDataPayload)

ContinuationAtNameResponse = _reflection.GeneratedProtocolMessageType('ContinuationAtNameResponse', (_message.Message,), {
  'DESCRIPTOR' : _CONTINUATIONATNAMERESPONSE,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.ContinuationAtNameResponse)
  })
_sym_db.RegisterMessage(ContinuationAtNameResponse)

ContinuationAtNamePayload = _reflection.GeneratedProtocolMessageType('ContinuationAtNamePayload', (_message.Message,), {
  'DESCRIPTOR' : _CONTINUATIONATNAMEPAYLOAD,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.ContinuationAtNamePayload)
  })
_sym_db.RegisterMessage(ContinuationAtNamePayload)

FindDeployResponse = _reflection.GeneratedProtocolMessageType('FindDeployResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDDEPLOYRESPONSE,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.FindDeployResponse)
  })
_sym_db.RegisterMessage(FindDeployResponse)

PrivateNamePreviewResponse = _reflection.GeneratedProtocolMessageType('PrivateNamePreviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _PRIVATENAMEPREVIEWRESPONSE,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.PrivateNamePreviewResponse)
  })
_sym_db.RegisterMessage(PrivateNamePreviewResponse)

PrivateNamePreviewPayload = _reflection.GeneratedProtocolMessageType('PrivateNamePreviewPayload', (_message.Message,), {
  'DESCRIPTOR' : _PRIVATENAMEPREVIEWPAYLOAD,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.PrivateNamePreviewPayload)
  })
_sym_db.RegisterMessage(PrivateNamePreviewPayload)

LastFinalizedBlockResponse = _reflection.GeneratedProtocolMessageType('LastFinalizedBlockResponse', (_message.Message,), {
  'DESCRIPTOR' : _LASTFINALIZEDBLOCKRESPONSE,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.LastFinalizedBlockResponse)
  })
_sym_db.RegisterMessage(LastFinalizedBlockResponse)

IsFinalizedResponse = _reflection.GeneratedProtocolMessageType('IsFinalizedResponse', (_message.Message,), {
  'DESCRIPTOR' : _ISFINALIZEDRESPONSE,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.IsFinalizedResponse)
  })
_sym_db.RegisterMessage(IsFinalizedResponse)

BondStatusResponse = _reflection.GeneratedProtocolMessageType('BondStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _BONDSTATUSRESPONSE,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.BondStatusResponse)
  })
_sym_db.RegisterMessage(BondStatusResponse)


DESCRIPTOR._options = None

_DEPLOYSERVICE = _descriptor.ServiceDescriptor(
  name='DeployService',
  full_name='casper.v1.DeployService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1614,
  serialized_end=2671,
  methods=[
  _descriptor.MethodDescriptor(
    name='doDeploy',
    full_name='casper.v1.DeployService.doDeploy',
    index=0,
    containing_service=None,
    input_type=CasperMessage__pb2._DEPLOYDATAPROTO,
    output_type=_DEPLOYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getBlock',
    full_name='casper.v1.DeployService.getBlock',
    index=1,
    containing_service=None,
    input_type=DeployServiceCommon__pb2._BLOCKQUERY,
    output_type=_BLOCKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='visualizeDag',
    full_name='casper.v1.DeployService.visualizeDag',
    index=2,
    containing_service=None,
    input_type=DeployServiceCommon__pb2._VISUALIZEDAGQUERY,
    output_type=_VISUALIZEBLOCKSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='machineVerifiableDag',
    full_name='casper.v1.DeployService.machineVerifiableDag',
    index=3,
    containing_service=None,
    input_type=DeployServiceCommon__pb2._MACHINEVERIFYQUERY,
    output_type=_MACHINEVERIFYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='showMainChain',
    full_name='casper.v1.DeployService.showMainChain',
    index=4,
    containing_service=None,
    input_type=DeployServiceCommon__pb2._BLOCKSQUERY,
    output_type=_BLOCKINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getBlocks',
    full_name='casper.v1.DeployService.getBlocks',
    index=5,
    containing_service=None,
    input_type=DeployServiceCommon__pb2._BLOCKSQUERY,
    output_type=_BLOCKINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='listenForDataAtName',
    full_name='casper.v1.DeployService.listenForDataAtName',
    index=6,
    containing_service=None,
    input_type=DeployServiceCommon__pb2._DATAATNAMEQUERY,
    output_type=_LISTENINGNAMEDATARESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='listenForContinuationAtName',
    full_name='casper.v1.DeployService.listenForContinuationAtName',
    index=7,
    containing_service=None,
    input_type=DeployServiceCommon__pb2._CONTINUATIONATNAMEQUERY,
    output_type=_CONTINUATIONATNAMERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='findDeploy',
    full_name='casper.v1.DeployService.findDeploy',
    index=8,
    containing_service=None,
    input_type=DeployServiceCommon__pb2._FINDDEPLOYQUERY,
    output_type=_FINDDEPLOYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='previewPrivateNames',
    full_name='casper.v1.DeployService.previewPrivateNames',
    index=9,
    containing_service=None,
    input_type=DeployServiceCommon__pb2._PRIVATENAMEPREVIEWQUERY,
    output_type=_PRIVATENAMEPREVIEWRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='lastFinalizedBlock',
    full_name='casper.v1.DeployService.lastFinalizedBlock',
    index=10,
    containing_service=None,
    input_type=DeployServiceCommon__pb2._LASTFINALIZEDBLOCKQUERY,
    output_type=_LASTFINALIZEDBLOCKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='isFinalized',
    full_name='casper.v1.DeployService.isFinalized',
    index=11,
    containing_service=None,
    input_type=DeployServiceCommon__pb2._ISFINALIZEDQUERY,
    output_type=_ISFINALIZEDRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='bondStatus',
    full_name='casper.v1.DeployService.bondStatus',
    index=12,
    containing_service=None,
    input_type=DeployServiceCommon__pb2._BONDSTATUSQUERY,
    output_type=_BONDSTATUSRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DEPLOYSERVICE)

DESCRIPTOR.services_by_name['DeployService'] = _DEPLOYSERVICE

# @@protoc_insertion_point(module_scope)
